==> v28.0.0.zip: nextcloud/apps/updatenotification/l10n/sv.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} är tillgänglig. Få mer information om hur du uppdaterar.",
    "Channel updated" : "Uppdateringskanal uppdaterad",
    "Web updater is disabled" : "Webbuppdateraren är inaktiverad",
    "Update notifications" : "Uppdateringsaviseringar",
    "The update server could not be reached since %d days to check for new updates." : "Uppdateringsservern kunde inte nås. Senaste kontakt för %d dagar sedan.",
    "Please check the Nextcloud and server log files for errors." : "Vänligen kontrollera ditt moln och dess serverloggar för felmeddelanden.",
    "Update to %1$s is available." : "Uppdatering till %1$s är tillgänglig.",
    "Update to {serverAndVersion} is available." : "En uppdatering till {serverAndVersion} finns tillgänglig.",
    "Update for {app} to version %s is available." : "Uppdatering för {app} till version %s är tillgänglig.",
    "Update notification" : "Uppdatera notifikation",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Visar uppdateringsaviseringar för Nextcloud och tillhandahåller SSO för uppdateraren.",
    "Update" : "Uppdatera",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Den version som du kör underhålls inte längre. Se till att uppdatera till en aktuell version så snart som möjligt.",
    "Apps missing compatible version" : "Appar som saknar kompatibel version",
    "View in store" : "Visa i butik",
    "Apps with compatible version" : "Appar med kompatibel version",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Observera att webbuppdateraren inte rekommenderas med fler än 100 användare! Använd kommandouppdateraren istället!",
    "Open updater" : "Öppna uppdateraren",
    "Download now" : "Hämta nu",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Web-uppdateraren är inaktiverad. Använd kommandoradsuppdateraren eller lämpligt uppdateringsmekanism för din installationsmetod (t.ex. Docker pull) för att uppdatera.",
    "What's new?" : "Vad är nytt?",
    "View changelog" : "Visa ändringslogg",
    "The update check is not yet finished. Please refresh the page." : "Uppdateringskontrollen är inte färdig ännu. Vänligen uppdatera sidan.",
    "Your version is up to date." : "Din version är uppdaterad.",
    "A non-default update server is in use to be checked for updates:" : "En icke-standard uppdateringsserver används för att kontrolleras efter uppdateringar:",
    "Update channel" : "Uppdateringskanal",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Att ändra uppdateringskanalen påverkar också apphanteringssidan. T.ex. efter att du har bytt till betakanalen kommer betaappuppdateringar att erbjudas dig på apphanteringssidan.",
    "Current update channel:" : "Aktuell uppdateringskanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Du kan alltid uppdatera till en nyare version, men du kan aldrig nedgradera till en mer stabil version.",
    "Notify members of the following groups about available updates:" : "Notifiera medlemmar i följande grupper om tillgängliga uppdateraingar:",
    "No groups" : "Inga grupper",
    "Only notifications for app updates are available." : "Endast notifikationer för appuppdateringar är tillgängliga.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valda uppdateringskanalen gör dedikerade aviseringar för servern förlegade.",
    "The selected update channel does not support updates of the server." : "Den valda uppdateringskanalen stödjer inte uppdateringar för servern.",
    "A new version is available: <strong>{newVersionString}</strong>" : "En ny version är tillgänglig: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Notera att efter en ny version släppts kommer den tidigast att synas efter första påföljande minor-versionen har släppts. Vi rullar ut uppdateringar utspritt över tid till våra användare och hoppar ibland över en version om problem upptäcks. Lär dig mer om uppdateringar och versions-kanaler på {link}",
    "Checked on {lastCheckedDate}" : "Kontrollerad {lastCheckedDate}",
    "Checking apps for compatible versions" : "Kontrollerar appar efter kompatibla versioner",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Se till att din config.php inte ställer in <samp>appstoreenabled</samp> till falsk.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Kunde inte ansluta till appbutiken eller så returnerades inga uppdateringar alls. Sök manuellt för uppdateringar och säkerställ att din server har tillgång till internet och kan ansluta till appbutiken.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Alla</strong> appar har en kompatibel version för denna version av Nextcloud.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Innehåller alltid den senaste patchnivån, men uppdateras inte omedelbart till nästa större version. Den uppdateringen sker när Nextcloud GmbH har utfört ytterligare verifiering och testning för storskaliga och kritiska installationer. Den här kanalen är endast tillgänglig för kunder och tillhandahåller Nextcloud Enterprise-paketet.",
    "Stable" : "Stabil",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Den senaste stabila versionen. Den är lämplig för regelbunden användning och kommer alltid att uppdatera till den senaste större mer omfattande versionen.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "En förhandsversion endast för att testa nya funktioner, inte för produktionsmiljöer.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> app har ingen tillgänglig kompatibel version för denna version av Nextcloud.","<strong>%n</strong> appar har ingen tillgänglig kompatibel version för denna version av Nextcloud."],
    "Please use the command line updater to update." : "Vänligen uppdatera via kommandotolken.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Du kan ändra uppdateringskanalen nedan, vilket också påverkar apphanteringssidan. T.ex. efter att du har bytt till betakanalen kommer betaappuppdateringar att erbjudas på apphanteringssidan.",
    "Update channel:" : "Uppdateringskanal:"
},
"nplurals=2; plural=(n != 1);");

==> v28.0.2rc3.zip: nextcloud/apps/updatenotification/l10n/sv.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} är tillgänglig. Få mer information om hur du uppdaterar.",
    "Channel updated" : "Uppdateringskanal uppdaterad",
    "Web updater is disabled" : "Webbuppdateraren är inaktiverad",
    "Update notifications" : "Uppdateringsaviseringar",
    "The update server could not be reached since %d days to check for new updates." : "Uppdateringsservern kunde inte nås. Senaste kontakt för %d dagar sedan.",
    "Please check the Nextcloud and server log files for errors." : "Vänligen kontrollera ditt moln och dess serverloggar för felmeddelanden.",
    "Update to %1$s is available." : "Uppdatering till %1$s är tillgänglig.",
    "Update to {serverAndVersion} is available." : "En uppdatering till {serverAndVersion} finns tillgänglig.",
    "Update for {app} to version %s is available." : "Uppdatering för {app} till version %s är tillgänglig.",
    "Update notification" : "Uppdatera notifikation",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Visar uppdateringsaviseringar för Nextcloud och tillhandahåller SSO för uppdateraren.",
    "Update" : "Uppdatera",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Den version som du kör underhålls inte längre. Se till att uppdatera till en aktuell version så snart som möjligt.",
    "Apps missing compatible version" : "Appar som saknar kompatibel version",
    "View in store" : "Visa i butik",
    "Apps with compatible version" : "Appar med kompatibel version",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Observera att webbuppdateraren inte rekommenderas med fler än 100 användare! Använd kommandouppdateraren istället!",
    "Open updater" : "Öppna uppdateraren",
    "Download now" : "Hämta nu",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Web-uppdateraren är inaktiverad. Använd kommandoradsuppdateraren eller lämpligt uppdateringsmekanism för din installationsmetod (t.ex. Docker pull) för att uppdatera.",
    "What's new?" : "Vad är nytt?",
    "View changelog" : "Visa ändringslogg",
    "The update check is not yet finished. Please refresh the page." : "Uppdateringskontrollen är inte färdig ännu. Vänligen uppdatera sidan.",
    "Your version is up to date." : "Din version är uppdaterad.",
    "A non-default update server is in use to be checked for updates:" : "En icke-standard uppdateringsserver används för att kontrolleras efter uppdateringar:",
    "Update channel" : "Uppdateringskanal",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Att ändra uppdateringskanalen påverkar också apphanteringssidan. T.ex. efter att du har bytt till betakanalen kommer betaappuppdateringar att erbjudas dig på apphanteringssidan.",
    "Current update channel:" : "Aktuell uppdateringskanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Du kan alltid uppdatera till en nyare version, men du kan aldrig nedgradera till en mer stabil version.",
    "Notify members of the following groups about available updates:" : "Notifiera medlemmar i följande grupper om tillgängliga uppdateraingar:",
    "No groups" : "Inga grupper",
    "Only notifications for app updates are available." : "Endast notifikationer för appuppdateringar är tillgängliga.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valda uppdateringskanalen gör dedikerade aviseringar för servern förlegade.",
    "The selected update channel does not support updates of the server." : "Den valda uppdateringskanalen stödjer inte uppdateringar för servern.",
    "A new version is available: <strong>{newVersionString}</strong>" : "En ny version är tillgänglig: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Notera att efter en ny version släppts kommer den tidigast att synas efter första påföljande minor-versionen har släppts. Vi rullar ut uppdateringar utspritt över tid till våra användare och hoppar ibland över en version om problem upptäcks. Lär dig mer om uppdateringar och versions-kanaler på {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Kontrollerad {lastCheckedDate} - Öppna ändringslogg",
    "Checking apps for compatible versions" : "Kontrollerar appar efter kompatibla versioner",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Se till att din config.php inte ställer in <samp>appstoreenabled</samp> till falsk.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Kunde inte ansluta till appbutiken eller så returnerades inga uppdateringar alls. Sök manuellt för uppdateringar och säkerställ att din server har tillgång till internet och kan ansluta till appbutiken.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Alla</strong> appar har en kompatibel version för denna version av Nextcloud.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Innehåller alltid den senaste patchnivån, men uppdateras inte omedelbart till nästa större version. Den uppdateringen sker när Nextcloud GmbH har utfört ytterligare verifiering och testning för storskaliga och kritiska installationer. Den här kanalen är endast tillgänglig för kunder och tillhandahåller Nextcloud Enterprise-paketet.",
    "Stable" : "Stabil",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Den senaste stabila versionen. Den är lämplig för regelbunden användning och kommer alltid att uppdatera till den senaste större mer omfattande versionen.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "En förhandsversion endast för att testa nya funktioner, inte för produktionsmiljöer.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> app har ingen tillgänglig kompatibel version för denna version av Nextcloud.","<strong>%n</strong> appar har ingen tillgänglig kompatibel version för denna version av Nextcloud."],
    "Please use the command line updater to update." : "Vänligen uppdatera via kommandotolken.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Du kan ändra uppdateringskanalen nedan, vilket också påverkar apphanteringssidan. T.ex. efter att du har bytt till betakanalen kommer betaappuppdateringar att erbjudas på apphanteringssidan.",
    "Update channel:" : "Uppdateringskanal:",
    "Checked on {lastCheckedDate}" : "Kontrollerad {lastCheckedDate}"
},
"nplurals=2; plural=(n != 1);");
